@@ -1,3 +1,18 @@
+#' @rdname groupGeneric.errors
+#'
+#' @details \subsection{\code{Summary}}{
+#' The methods \code{all} and \code{any} are not supported for \code{errors}
+#' objects and fail with an informative message. \code{min}, \code{max} (and
+#' \code{range}) return the minimum or (and) maximum value minus/plus its error.
+#' \code{sum} and \code{prod} propagate the error as expected from the first-order
+#' Taylor series method.}
+#'
+#' @examples
+#' c(min(x), max(x))
+#' range(x)
+#' sum(y)
+#' prod(y)
+#'
 #' @export
 Summary.errors <- function(..., na.rm = FALSE) {
   x <- c(...)
@@ -5,21 +20,15 @@ Summary.errors <- function(..., na.rm = FALSE) {
     .Generic,
     "all" = , "any" =
       stop("method not supported for `errors` objects"),
+    "sum" = structure(NextMethod(), "errors" = propagate(cbind(errors(x))), class = "errors"),
     "prod" = {
       value <- NextMethod()
       e <- propagate(cbind(errors(x) * value / .v(x)))
-      set_errors(value, e)
+      structure(value, "errors" = e, class = "errors")
     },
-    {
-      e <- switch(
-        .Generic,
-        "sum" = propagate(cbind(errors(x))),
-        "max" = errors(x)[which.max(x)],
-        "min" = errors(x)[which.min(x)],
-        "range" = c(errors(min(x)), errors(max(x)))
-      )
-      structure(NextMethod(), "errors" = e, class = "errors")
-    }
+    "max" = NextMethod() + errors(x)[which.max(x)],
+    "min" = NextMethod() - errors(x)[which.min(x)],
+    "range" = c(min(x), max(x))
   )
 }
 
